Summary:   GNU Ada95 Compiler based on gcc (GNAT)
Name:      gnat

%define    GNAT_VERSION  3.11
%define    GCC_VERSION   2.8.1
%define    BASE_VERSION gcc-%{GCC_VERSION}
%define    ADA_BASE /usr/lib/Ada

Version:   %{GNAT_VERSION}p
Release:   2

Source:    ftp://ftp.gnu.org/pub/gnu/%{BASE_VERSION}.tar.gz 
Source1:   ftp://ftp.cs.nyu.edu/pub/gnat/%{name}-%{version}-src.tar.gz
Source2:   ftp://ftp.cs.nyu.edu/pub/gnat/%{name}-%{version}-docs.tar.gz
Source3:   ftp://ftp.cs.nyu.edu/pub/gnat/asis/asis-%{version}-src.tar.gz
Source4:   ftp://ftp.cs.nyu.edu/pub/gnat/glade/glade-%{version}.tar.gz
Source5:   gnat-profile.tar.gz
Source6:   gnat-boot-warn.txt
Source7:   HelloWorld.tar.gz
Patch0:    gcc281.patch
Patch1:    gnat311p.patch
Patch2:    asis311p.patch
Patch3:    glade311p.patch

URL:       http://www.gnat.com/
Copyright: LGPL (modified)
Group:     Development/Languages
Requires:  binutils >= 2.9.1, gnat-rts = %{version}
Obsoletes: gnat
Provides:  gnat
BuildRoot: /tmp/%{name}-%{version}-root

%description
This package adds Ada95 support to the GNU C compiler. Ada95
is the object oriented successor of the Ada83 language. To build this
package from sources you must have installed a binary version (bootstrap).

%package rts
Summary: Runtime libraries for GNU Ada95 compiler (GNAT)
Group: Libraries

%description rts
This package includes the shared libraries required to run programs compiled
with the GNU Ada compiler (GNAT) if they are compiled to uses shared libs.
 
%prep
# We issue a warning to remind the person doing the build that
# the binary must be installed 
cat $RPM_SOURCE_DIR/gnat-boot-warn.txt
rpm -q gnat

%setup -q -n %{BASE_VERSION}
%setup -q -T -D -a 1 -n %{BASE_VERSION}
%setup -q -T -D -a 2 -n %{BASE_VERSION}
%setup -q -T -D -a 3 -n %{BASE_VERSION}
%setup -q -T -D -a 4 -n %{BASE_VERSION}
%setup -q -T -D -a 5 -n %{BASE_VERSION}

%patch0 -p1 -b .gcc
%patch1 -p0 -b .gnat
%patch2 -p0 -b .asis
%patch3 -p0 -b .glade

# Move the GNAT sources ada directory under the gcc source tree
# and do what they say in the GNAT build readme.
mv gnat-%{version}-src/src/ada .
patch -p0 < gnat-%{version}-src/src/gcc-281.dif
touch ada/treeprs.ada ada/a-[es]info.h ada/nmake.ad[bs]
touch c-gperf.h

%build
# Create the required directory structure for the binary package
rm -rf $RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT/usr/info
mkdir -p $RPM_BUILD_ROOT/usr/bin
mkdir -p $RPM_BUILD_ROOT/doc/examples
mkdir -p $RPM_BUILD_ROOT/doc/asis
mkdir -p $RPM_BUILD_ROOT/doc/glade
mkdir -p $RPM_BUILD_ROOT%{ADA_BASE}/include
mkdir -p $RPM_BUILD_ROOT%{ADA_BASE}/objects
mkdir -p $RPM_BUILD_ROOT/etc/profile.d

# Do the gcc/gnat build in a separate directory
rm -rf obj-$RPM_ARCH-linux
mkdir obj-$RPM_ARCH-linux
cd obj-$RPM_ARCH-linux

CC="gnatgcc -pipe" ; export CC

CFLAGS="$RPM_OPT_FLAGS" LDFLAGS=-s           \
LIBGCC=libgnatgcc.a                          \
../configure  --prefix=/usr                  \
              --host=$RPM_ARCH-Ada95-linux   \
	      --target=$RPM_ARCH-Ada95-linux \
	      --build=$RPM_ARCH-Ada95-linux

#
# Now build the C and the Ada compilers and the Ada runtime (shared).
#
PATH=/usr/bin:/bin:/sbin:/usr/sbin:/usr/local/bin:/usr/local/sbin
export PATH
make CFLAGS="$RPM_OPT_FLAGS" LDFLAGS=-s                                 \
	LIBGCC=libgnatgcc.a                                             \
	MAKEINFO="makeinfo --no-split" LANGUAGES="c ada"
# make CFLAGS="$RPM_OPT_FLAGS" LDFLAGS=-s LIBGCC=libgnatgcc.a           \
#	LANGUAGES="c ada" bootstrap
make CFLAGS="$RPM_OPT_FLAGS" LDFLAGS=-s LIBGCC=libgnatgcc.a             \
	LANGUAGES="c ada" gnattools
make CFLAGS="$RPM_OPT_FLAGS" GNATLIBCFLAGS="$RPM_OPT_FLAGS -UIN_GCC"    \
	LDFLAGS=-s LIBGCC=libgnatgcc.a LANGUAGES="c ada" gnatlib-shared

#
# At this point we are still in the gcc/gnat build directory. For the
# following builds we use the just built C and Ada compiler and the
# Ada runtime. We store those locations in some environment variables.
#
GNAT_RTS="`pwd`/ada/rts" ; export GNAT_RTS
BD="`pwd`" ; export BD
CC="${BD}/xgcc -B${BD}/" ; export CC

#
# Now we build GLADE, the GNU Ada distributed environment system.
# We build it as a shared library version and merge it with the
# GNAT runtime system. The GLADE makefiles have been patched
# accordingly.
#
cd ../glade-%{version}
CFLAGS="$RPM_OPT_FLAGS -fPIC" \
./configure --prefix=%{ADA_BASE}             \
              --host=$RPM_ARCH-Ada95-linux   \
	      --target=$RPM_ARCH-Ada95-linux \
	      --build=$RPM_ARCH-Ada95-linux

ADA_OBJECTS_PATH=${GNAT_RTS} \
ADA_INCLUDE_PATH=${GNAT_RTS} \
make	CC="$CC" \
	CFLAGS="$RPM_OPT_FLAGS -fPIC" \
	GMFLAGS="-aI${GNAT_RTS} \
	         -aO${GNAT_RTS} \
	         --GCC=\"${CC}\" --GNATBIND=${BD}/gnatbind \
	         --GNATLINK=${BD}/gnatlink" \
	all

#
# Finally we build ASIS for GNAT. We build the shared library version
# and store objects and packages in separate directories under %{ADA_BASE}
#
cd ../asis-%{version}-src
ADA_OBJECTS_PATH= \
ADA_INCLUDE_PATH= \
make	CC="$CC" \
	CFLAGS="$RPM_OPT_FLAGS" \
	GMFLAGS="-aI${GNAT_RTS} \
	         -aO${GNAT_RTS} \
	         --GCC=\"${CC}\" --GNATBIND=${BD}/gnatbind \
	         --GNATLINK=${BD}/gnatlink" \
	IDIR=$RPM_BUILD_ROOT%{ADA_BASE}/include \
	ODIR=$RPM_BUILD_ROOT%{ADA_BASE}/objects \
	LDIR=$RPM_BUILD_ROOT%{ADA_BASE}/objects \
	all
cd ..

%install
cp gnat.sh  $RPM_BUILD_ROOT/etc/profile.d/gnat.sh
cp gnat.csh $RPM_BUILD_ROOT/etc/profile.d/gnat.csh

#
# Copy the ASIS sample application README's into the doc directory.
cp asis-%{version}-src/examples/gnatelim/README   $RPM_BUILD_ROOT/doc/README.gnatelim
cp asis-%{version}-src/examples/gnatstub/README   $RPM_BUILD_ROOT/doc/README.gnatstub
#
# Copy the ASIS sample binaries to the global binary location
cp asis-%{version}-src/examples/gnatelim/gnatelim $RPM_BUILD_ROOT/usr/bin
cp asis-%{version}-src/examples/gnatstub/gnatstub $RPM_BUILD_ROOT/usr/bin

#
# Install the C and Ada compiler as well as the Ada runtime directory.
#
cd obj-$RPM_ARCH-linux
PATH=$PATH:/sbin:/usr/sbin
make prefix=$RPM_BUILD_ROOT/usr MAKEINFO="makeinfo --no-split" \
	LIBGCC=libgnatgcc.a \
	INSTALL_LIBGCC=install-alt-libgcc \
	LANGUAGES="c ada" install
rm -rf $RPM_BUILD_ROOT/usr/info
mv -f $RPM_BUILD_ROOT/usr/bin/gcc $RPM_BUILD_ROOT/usr/bin/gnatgcc
FULLVER=`$RPM_BUILD_ROOT/usr/bin/$RPM_ARCH-*linux*-gcc --version | cut -d' ' -f1`
FULLPATH=$(dirname $RPM_BUILD_ROOT/usr/lib/gcc-lib/$RPM_ARCH-*/$FULLVER/cc1)
strip $FULLPATH/{cc1,cpp,gnat1}
strip `find $RPM_BUILD_ROOT/usr/bin -type f`

GNAT_RTS="`pwd`/ada/rts" ; export GNAT_RTS
BD="`pwd`" ; export BD
CC="${BD}/xgcc -B${BD}/" ; export CC
cd ..

#
# Install gnathtml, it's a very nice new tool :-)
cp -p ada/gnathtml.pl $RPM_BUILD_ROOT/usr/bin
chmod +x $RPM_BUILD_ROOT/usr/bin/gnathtml.pl
ln -sf gnathtml.pl $RPM_BUILD_ROOT/usr/bin/gnathtml

# Move the GNAT shared runtime library under its official name into /usr/lib
mv $RPM_BUILD_ROOT/usr/lib/gcc-lib/$RPM_ARCH-Ada95-linux/$FULLVER/adalib/libgnat.so \
   $RPM_BUILD_ROOT/usr/lib/libgnat.so.%{GNAT_VERSION}

# Make links to the GNAT shared runtime library at the right places.
ln -sf libgnat.so.%{GNAT_VERSION} $RPM_BUILD_ROOT/usr/lib/libgnat.so
ln -sf /usr/lib/libgnat.so.%{GNAT_VERSION} \
	$RPM_BUILD_ROOT/usr/lib/gcc-lib/$RPM_ARCH-Ada95-linux/$FULLVER/adalib/libgnat.so 
ln -sf adalib/libgnat.so $RPM_BUILD_ROOT/usr/lib/gcc-lib/$RPM_ARCH-Ada95-linux/$FULLVER/libgnat.so

#
# Now we install the GLADE files. Actually they will go to some location
# under $BUILD_ROOT (the original Makefile is more or less unmodified).
# But later in this build script me merge the GLADE runtime into the
# GNAT runtime.
cd glade-%{version}
ADA_OBJECTS_PATH=${GNAT_RTS} \
ADA_INCLUDE_PATH=${GNAT_RTS} \
make	CC="$CC" \
	CFLAGS="$RPM_OPT_FLAGS" \
	prefix=$RPM_BUILD_ROOT%{ADA_BASE} \
	GMFLAGS="-aI${GNAT_RTS} \
	         -aO${GNAT_RTS} \
	         --GCC=\"${CC}\" --GNATBIND=${BD}/gnatbind \
	         --GNATLINK=${BD}/gnatlink" \
	install
cd ..

#
# This is the merge of the GNAT and the GLADE runtime. All that
# works as we do it here, because both runtimes are compiled with
# the -fPIC option.
#
mkdir gnatlib && cd gnatlib
# First we extract all objects from the GNAT runtime modified
# by the GLADE build.
ar xv $RPM_BUILD_ROOT%{ADA_BASE}/lib/garlic/libgnat.a \
  `ar t $RPM_BUILD_ROOT%{ADA_BASE}/lib/garlic/libgnat.a`
# Second we extract all objects from the GLADE runtime created
# by the GLADE build.
ar xv $RPM_BUILD_ROOT%{ADA_BASE}/lib/garlic/libgarlic.a \
  `ar t $RPM_BUILD_ROOT%{ADA_BASE}/lib/garlic/libgarlic.a`
# Now we create one single static GNAT runtime 
ar cq libgnat.a *.o
ranlib libgnat.a
# And because all objects are compiled with -fPIC, we link
# one single shared GNAT runtime library.
gcc -shared -o libgnat.so.%{GNAT_VERSION} -Wl,-soname,libgnat.so.%{GNAT_VERSION} \
  *.o -lpthread -lm
cp -pf libgnat.so.%{GNAT_VERSION} $RPM_BUILD_ROOT/usr/lib
cp -pf libgnat.a \
  $RPM_BUILD_ROOT/usr/lib/gcc-lib/$RPM_ARCH-Ada95-linux/$FULLVER/adalib
cd ..
rm -rf gnatlib

#
# Finally we copy all the GLADE object (.ali) and package files
# into the GNAT runtime directories.
cp -pf $RPM_BUILD_ROOT%{ADA_BASE}/lib/garlic/*.ali \
  $RPM_BUILD_ROOT/usr/lib/gcc-lib/$RPM_ARCH-Ada95-linux/$FULLVER/adalib
cp -pf $RPM_BUILD_ROOT%{ADA_BASE}/lib/garlic/*.ad? \
  $RPM_BUILD_ROOT/usr/lib/gcc-lib/$RPM_ARCH-Ada95-linux/$FULLVER/adainclude

cp -pf $RPM_BUILD_ROOT%{ADA_BASE}/bin/gnatdist $RPM_BUILD_ROOT/usr/bin/gnatdist
strip $RPM_BUILD_ROOT/usr/bin/gnatdist

#
# Move the shared ASIS runtime to the default location and make
# symbolic links at the right places.
mv $RPM_BUILD_ROOT/usr/lib/Ada/objects/libasis.so \
   $RPM_BUILD_ROOT/usr/lib/libasis.so.%{GNAT_VERSION}
ln -sf libasis.so.%{GNAT_VERSION} $RPM_BUILD_ROOT/usr/lib/libasis.so
ln -sf /usr/lib/libasis.so.%{GNAT_VERSION} $RPM_BUILD_ROOT/usr/lib/Ada/objects/libasis.so 

#
# Finally copy all the documentation and samples to the doc directory
#
cp -p  gnat-%{version}-docs/gnat_*.html $RPM_BUILD_ROOT/doc
cp -p  gnat-%{version}-docs/gnat_*.ps   $RPM_BUILD_ROOT/doc
cp -p  gnat-%{version}-docs/gnat_*.txt  $RPM_BUILD_ROOT/doc
cp -p  gnat-%{version}-src/features     $RPM_BUILD_ROOT/doc
cp -p  gnat-%{version}-src/gnatinfo.txt $RPM_BUILD_ROOT/doc
cp -pr gnat-%{version}-src/examples     $RPM_BUILD_ROOT/doc

cp -p asis-%{version}-src/documentation/asisinfo.txt $RPM_BUILD_ROOT/doc/asis
cp -p asis-%{version}-src/documentation/asis_rm.txt  $RPM_BUILD_ROOT/doc/asis
cp -p asis-%{version}-src/documentation/asis_ug.txt  $RPM_BUILD_ROOT/doc/asis
cp -p asis-%{version}-src/documentation/features.txt $RPM_BUILD_ROOT/doc/asis

cp -p  glade-%{version}/README     $RPM_BUILD_ROOT/doc/glade
cp -p  glade-%{version}/COPYING    $RPM_BUILD_ROOT/doc/glade
cp -p  glade-%{version}/NEWS       $RPM_BUILD_ROOT/doc/glade
cp -p  glade-%{version}/Doc/*      $RPM_BUILD_ROOT/doc/glade
cp -pr glade-%{version}/Examples/  $RPM_BUILD_ROOT/doc/glade

tar -C $RPM_BUILD_ROOT/doc/glade/Examples \
	-xzf $RPM_SOURCE_DIR/HelloWorld.tar.gz

%post rts
/sbin/ldconfig

%postun rts
/sbin/ldconfig

%files
%defattr(-,root,root)
%doc $RPM_BUILD_ROOT/doc/*
/etc/profile.d/gnat.sh
/etc/profile.d/gnat.csh
/usr/bin/gnatelim
/usr/bin/gnatstub
/usr/bin/gnatbind
/usr/bin/gnatbl
/usr/bin/gnatchop
/usr/bin/gnatcmd
/usr/bin/gnatkr
/usr/bin/gnatlink
/usr/bin/gnatls
/usr/bin/gnatmake
/usr/bin/gnatmem
/usr/bin/gnatprep
/usr/bin/gnatpsta
/usr/bin/gnatpsys
/usr/bin/gnatxref
/usr/bin/gnatfind
/usr/bin/gnatgcc
/usr/bin/gnathtml
/usr/bin/gnathtml.pl
/usr/bin/gnatdist
/usr/lib/Ada/include/alloc.ads
/usr/lib/Ada/include/atree.ads
/usr/lib/Ada/include/casing.ads
/usr/lib/Ada/include/csets.ads
/usr/lib/Ada/include/debug.ads
/usr/lib/Ada/include/einfo.ads
/usr/lib/Ada/include/elists.ads
/usr/lib/Ada/include/fname.ads
/usr/lib/Ada/include/gnatvsn.ads
/usr/lib/Ada/include/hostparm.ads
/usr/lib/Ada/include/krunch.ads
/usr/lib/Ada/include/lib.ads
/usr/lib/Ada/include/namet.ads
/usr/lib/Ada/include/nlists.ads
/usr/lib/Ada/include/opt.ads
/usr/lib/Ada/include/output.ads
/usr/lib/Ada/include/scans.ads
/usr/lib/Ada/include/sinfo.ads
/usr/lib/Ada/include/sinput.ads
/usr/lib/Ada/include/snames.ads
/usr/lib/Ada/include/stand.ads
/usr/lib/Ada/include/stringt.ads
/usr/lib/Ada/include/table.ads
/usr/lib/Ada/include/tree_in.ads
/usr/lib/Ada/include/tree_io.ads
/usr/lib/Ada/include/types.ads
/usr/lib/Ada/include/uintp.ads
/usr/lib/Ada/include/uname.ads
/usr/lib/Ada/include/urealp.ads
/usr/lib/Ada/include/widechar.ads
/usr/lib/Ada/include/atree.adb
/usr/lib/Ada/include/casing.adb
/usr/lib/Ada/include/csets.adb
/usr/lib/Ada/include/debug.adb
/usr/lib/Ada/include/einfo.adb
/usr/lib/Ada/include/elists.adb
/usr/lib/Ada/include/fname.adb
/usr/lib/Ada/include/krunch.adb
/usr/lib/Ada/include/lib.adb
/usr/lib/Ada/include/lib-list.adb
/usr/lib/Ada/include/lib-sort.adb
/usr/lib/Ada/include/namet.adb
/usr/lib/Ada/include/nlists.adb
/usr/lib/Ada/include/opt.adb
/usr/lib/Ada/include/output.adb
/usr/lib/Ada/include/scans.adb
/usr/lib/Ada/include/sinfo.adb
/usr/lib/Ada/include/sinput.adb
/usr/lib/Ada/include/snames.adb
/usr/lib/Ada/include/stand.adb
/usr/lib/Ada/include/a4g.ads
/usr/lib/Ada/include/stringt.adb
/usr/lib/Ada/include/table.adb
/usr/lib/Ada/include/tree_in.adb
/usr/lib/Ada/include/tree_io.adb
/usr/lib/Ada/include/types.adb
/usr/lib/Ada/include/uintp.adb
/usr/lib/Ada/include/uname.adb
/usr/lib/Ada/include/urealp.adb
/usr/lib/Ada/include/widechar.adb
/usr/lib/Ada/include/a4g-a_alloc.ads
/usr/lib/Ada/include/a4g-a_debug.ads
/usr/lib/Ada/include/a4g-a_elists.ads
/usr/lib/Ada/include/a4g-a_opt.ads
/usr/lib/Ada/include/a4g-a_osint.ads
/usr/lib/Ada/include/a4g-a_output.ads
/usr/lib/Ada/include/a4g-a_sem.ads
/usr/lib/Ada/include/a4g-a_sinput.ads
/usr/lib/Ada/include/a4g-a_types.ads
/usr/lib/Ada/include/a4g-contt.ads
/usr/lib/Ada/include/a4g-contt-dp.ads
/usr/lib/Ada/include/a4g-contt-sd.ads
/usr/lib/Ada/include/a4g-contt-tt.ads
/usr/lib/Ada/include/a4g-contt-ut.ads
/usr/lib/Ada/include/a4g-cu_info1.ads
/usr/lib/Ada/include/a4g-cu_info2.ads
/usr/lib/Ada/include/a4g-c_u_info.ads
/usr/lib/Ada/include/a4g-decl_sem.ads
/usr/lib/Ada/include/a4g-defaults.ads
/usr/lib/Ada/include/a4g-encl_el.ads
/usr/lib/Ada/include/a4g-encl_el_old.ads
/usr/lib/Ada/include/a4g-expr_sem.ads
/usr/lib/Ada/include/a4g-get_unit.ads
/usr/lib/Ada/include/a4g-gnat_int.ads
/usr/lib/Ada/include/a4g-int_knds.ads
/usr/lib/Ada/include/a4g-itests.ads
/usr/lib/Ada/include/a4g-knd_conv.ads
/usr/lib/Ada/include/a4g-mapping.ads
/usr/lib/Ada/include/a4g-nencl_el.ads
/usr/lib/Ada/include/a4g-norm.ads
/usr/lib/Ada/include/a4g-queries.ads
/usr/lib/Ada/include/a4g-s_dir.ads
/usr/lib/Ada/include/a4g-skip_tb.ads
/usr/lib/Ada/include/a4g-span_beginning.ads
/usr/lib/Ada/include/asis.ads
/usr/lib/Ada/include/a4g-span_end.ads
/usr/lib/Ada/include/a4g-s_u_info.ads
/usr/lib/Ada/include/a4g-tree_rec.ads
/usr/lib/Ada/include/a4g-u_conv.ads
/usr/lib/Ada/include/a4g-ulists.ads
/usr/lib/Ada/include/a4g-unit_rec.ads
/usr/lib/Ada/include/a4g-vcheck.ads
/usr/lib/Ada/include/asis-ada_environments.ads
/usr/lib/Ada/include/asis-ada_environments-containers.ads
/usr/lib/Ada/include/asis-clauses.ads
/usr/lib/Ada/include/asis-compilation_units.ads
/usr/lib/Ada/include/asis-compilation_units-relations.ads
/usr/lib/Ada/include/asis-compilation_units-times.ads
/usr/lib/Ada/include/asis-declarations.ads
/usr/lib/Ada/include/asis-definitions.ads
/usr/lib/Ada/include/asis-elements.ads
/usr/lib/Ada/include/asis-errors.ads
/usr/lib/Ada/include/asis-exceptions.ads
/usr/lib/Ada/include/asis-expressions.ads
/usr/lib/Ada/include/asis-extensions.ads
/usr/lib/Ada/include/asis-extensions-flat_kinds.ads
/usr/lib/Ada/include/asis-ids.ads
/usr/lib/Ada/include/asis-implementation.ads
/usr/lib/Ada/include/asis-implementation-permissions.ads
/usr/lib/Ada/include/asis-iterator.ads
/usr/lib/Ada/include/asis-set_get.ads
/usr/lib/Ada/include/asis-statements.ads
/usr/lib/Ada/include/asis-text.ads
/usr/lib/Ada/include/asis-text-set_get.ads
/usr/lib/Ada/include/a4g-a_debug.adb
/usr/lib/Ada/include/a4g-a_elists.adb
/usr/lib/Ada/include/a4g-a_opt.adb
/usr/lib/Ada/include/a4g-a_osint.adb
/usr/lib/Ada/include/a4g-a_output.adb
/usr/lib/Ada/include/a4g-a_sem.adb
/usr/lib/Ada/include/a4g-norm.adb
/usr/lib/Ada/include/a4g-a_sinput.adb
/usr/lib/Ada/include/a4g-a_types.adb
/usr/lib/Ada/include/a4g-contt.adb
/usr/lib/Ada/include/a4g-contt-dp.adb
/usr/lib/Ada/include/a4g-contt-sd.adb
/usr/lib/Ada/include/a4g-contt-tt.adb
/usr/lib/Ada/include/a4g-contt-ut.adb
/usr/lib/Ada/include/a4g-cu_info1.adb
/usr/lib/Ada/include/a4g-cu_info2.adb
/usr/lib/Ada/include/a4g-c_u_info.adb
/usr/lib/Ada/include/a4g-decl_sem.adb
/usr/lib/Ada/include/a4g-defaults.adb
/usr/lib/Ada/include/a4g-encl_el.adb
/usr/lib/Ada/include/a4g-encl_el_old.adb
/usr/lib/Ada/include/a4g-expr_sem.adb
/usr/lib/Ada/include/a4g-get_unit.adb
/usr/lib/Ada/include/a4g-gnat_int.adb
/usr/lib/Ada/include/a4g-itests.adb
/usr/lib/Ada/include/a4g-knd_conv.adb
/usr/lib/Ada/include/a4g-mapping.adb
/usr/lib/Ada/include/a4g-nencl_el.adb
/usr/lib/Ada/include/a4g-queries.adb
/usr/lib/Ada/include/a4g-s_dir.adb
/usr/lib/Ada/include/a4g-skip_tb.adb
/usr/lib/Ada/include/a4g-span_beginning.adb
/usr/lib/Ada/include/a4g-span_end.adb
/usr/lib/Ada/include/a4g-s_u_info.adb
/usr/lib/Ada/include/a4g-u_conv.adb
/usr/lib/Ada/include/a4g-vcheck.adb
/usr/lib/Ada/include/asis-ada_environments.adb
/usr/lib/Ada/include/asis-ada_environments-containers.adb
/usr/lib/Ada/include/asis-clauses.adb
/usr/lib/Ada/include/asis-compilation_units.adb
/usr/lib/Ada/include/asis-compilation_units-relations.adb
/usr/lib/Ada/include/asis-compilation_units-times.adb
/usr/lib/Ada/include/asis-declarations.adb
/usr/lib/Ada/include/asis-definitions.adb
/usr/lib/Ada/include/asis-elements.adb
/usr/lib/Ada/include/asis-expressions.adb
/usr/lib/Ada/include/asis-extensions.adb
/usr/lib/Ada/include/asis-extensions-flat_kinds.adb
/usr/lib/Ada/include/asis-ids.adb
/usr/lib/Ada/include/asis-implementation.adb
/usr/lib/Ada/include/asis-implementation-permissions.adb
/usr/lib/Ada/include/asis-iterator.adb
/usr/lib/Ada/include/asis-set_get.adb
/usr/lib/Ada/include/asis-statements.adb
/usr/lib/Ada/include/asis-text.adb
/usr/lib/Ada/include/asis-text-set_get.adb
/usr/lib/Ada/objects/a4g-a_alloc.ali
/usr/lib/Ada/objects/a4g-a_debug.ali
/usr/lib/Ada/objects/a4g-a_elists.ali
/usr/lib/Ada/objects/a4g.ali
/usr/lib/Ada/objects/a4g-a_opt.ali
/usr/lib/Ada/objects/a4g-a_osint.ali
/usr/lib/Ada/objects/a4g-a_output.ali
/usr/lib/Ada/objects/a4g-a_sem.ali
/usr/lib/Ada/objects/a4g-a_sinput.ali
/usr/lib/Ada/objects/a4g-a_types.ali
/usr/lib/Ada/objects/a4g-contt.ali
/usr/lib/Ada/objects/a4g-contt-dp.ali
/usr/lib/Ada/objects/a4g-contt-sd.ali
/usr/lib/Ada/objects/a4g-contt-tt.ali
/usr/lib/Ada/objects/a4g-contt-ut.ali
/usr/lib/Ada/objects/a4g-cu_info1.ali
/usr/lib/Ada/objects/a4g-cu_info2.ali
/usr/lib/Ada/objects/a4g-c_u_info.ali
/usr/lib/Ada/objects/a4g-decl_sem.ali
/usr/lib/Ada/objects/a4g-defaults.ali
/usr/lib/Ada/objects/a4g-encl_el.ali
/usr/lib/Ada/objects/a4g-encl_el_old.ali
/usr/lib/Ada/objects/a4g-expr_sem.ali
/usr/lib/Ada/objects/a4g-get_unit.ali
/usr/lib/Ada/objects/a4g-gnat_int.ali
/usr/lib/Ada/objects/a4g-int_knds.ali
/usr/lib/Ada/objects/a4g-itests.ali
/usr/lib/Ada/objects/a4g-knd_conv.ali
/usr/lib/Ada/objects/a4g-mapping.ali
/usr/lib/Ada/objects/a4g-nencl_el.ali
/usr/lib/Ada/objects/a4g-norm.ali
/usr/lib/Ada/objects/a4g-queries.ali
/usr/lib/Ada/objects/a4g-s_dir.ali
/usr/lib/Ada/objects/a4g-skip_tb.ali
/usr/lib/Ada/objects/a4g-span_beginning.ali
/usr/lib/Ada/objects/a4g-span_end.ali
/usr/lib/Ada/objects/a4g-s_u_info.ali
/usr/lib/Ada/objects/a4g-tree_rec.ali
/usr/lib/Ada/objects/a4g-u_conv.ali
/usr/lib/Ada/objects/a4g-unit_rec.ali
/usr/lib/Ada/objects/a4g-vcheck.ali
/usr/lib/Ada/objects/asis.ali
/usr/lib/Ada/objects/alloc.ali
/usr/lib/Ada/objects/asis-ada_environments.ali
/usr/lib/Ada/objects/asis-ada_environments-containers.ali
/usr/lib/Ada/objects/asis-clauses.ali
/usr/lib/Ada/objects/asis-compilation_units.ali
/usr/lib/Ada/objects/asis-compilation_units-relations.ali
/usr/lib/Ada/objects/asis-compilation_units-times.ali
/usr/lib/Ada/objects/asis-declarations.ali
/usr/lib/Ada/objects/asis-definitions.ali
/usr/lib/Ada/objects/asis-elements.ali
/usr/lib/Ada/objects/asis-errors.ali
/usr/lib/Ada/objects/asis-exceptions.ali
/usr/lib/Ada/objects/asis-expressions.ali
/usr/lib/Ada/objects/asis-extensions.ali
/usr/lib/Ada/objects/asis-ids.ali
/usr/lib/Ada/objects/asis-implementation.ali
/usr/lib/Ada/objects/asis-implementation-permissions.ali
/usr/lib/Ada/objects/asis-iterator.ali
/usr/lib/Ada/objects/asis-set_get.ali
/usr/lib/Ada/objects/asis-statements.ali
/usr/lib/Ada/objects/asis-text.ali
/usr/lib/Ada/objects/asis-text-set_get.ali
/usr/lib/Ada/objects/atree.ali
/usr/lib/Ada/objects/casing.ali
/usr/lib/Ada/objects/csets.ali
/usr/lib/Ada/objects/debug.ali
/usr/lib/Ada/objects/einfo.ali
/usr/lib/Ada/objects/elists.ali
/usr/lib/Ada/objects/fname.ali
/usr/lib/Ada/objects/gnatvsn.ali
/usr/lib/Ada/objects/hostparm.ali
/usr/lib/Ada/objects/krunch.ali
/usr/lib/Ada/objects/lib.ali
/usr/lib/Ada/objects/namet.ali
/usr/lib/Ada/objects/nlists.ali
/usr/lib/Ada/objects/opt.ali
/usr/lib/Ada/objects/output.ali
/usr/lib/Ada/objects/sinfo.ali
/usr/lib/Ada/objects/sinput.ali
/usr/lib/Ada/objects/snames.ali
/usr/lib/Ada/objects/stand.ali
/usr/lib/Ada/objects/stringt.ali
/usr/lib/Ada/objects/table.ali
/usr/lib/Ada/objects/tree_in.ali
/usr/lib/Ada/objects/tree_io.ali
/usr/lib/Ada/objects/types.ali
/usr/lib/Ada/objects/uintp.ali
/usr/lib/Ada/objects/uname.ali
/usr/lib/Ada/objects/urealp.ali
/usr/lib/Ada/objects/widechar.ali
/usr/lib/Ada/objects/libasis.a
/usr/lib/Ada/objects/libasis.so
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/include/syslimits.h
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/include/stdarg.h
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/include/stddef.h
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/include/varargs.h
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/include/va-alpha.h
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/include/va-h8300.h
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/include/va-i860.h
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/include/va-i960.h
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/include/va-mips.h
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/include/va-m88k.h
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/include/va-mn10200.h
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/include/va-mn10300.h
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/include/va-pa.h
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/include/va-pyr.h
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/include/va-sparc.h
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/include/va-clipper.h
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/include/va-spur.h
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/include/va-m32r.h
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/include/va-sh.h
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/include/va-v850.h
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/include/va-arc.h
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/include/iso646.h
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/include/va-ppc.h
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/include/proto.h
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/include/typeinfo
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/include/exception
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/include/new
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/include/new.h
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/include/limits.h
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/include/README
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/include/float.h
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/a-cadeob.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/a-caldel.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/a-calend.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/a-chahan.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/a-charac.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/a-chlat1.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/a-colien.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/a-comlin.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/a-cwila1.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/ada.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/a-decima.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/a-dynpri.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/a-except.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/a-filico.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/a-finali.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/a-flteio.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/a-fwteio.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/a-inteio.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/a-interr.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/a-intnam.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/a-ioexce.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/a-iwteio.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/a-lfteio.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/a-lfwtio.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/a-liteio.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/a-liwtio.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/a-llftio.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/a-llfwti.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/a-llitio.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/a-lliwti.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/a-ncelfu.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/a-nlcefu.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/a-nlcoty.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/a-nlelfu.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/a-nllcef.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/a-nllcty.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/a-nllefu.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/a-nscefu.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/a-nscoty.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/a-nselfu.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/a-nucoty.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/a-nuelfu.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/a-nuflra.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/a-numaux.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/a-numeri.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/a-reatim.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/a-retide.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/a-sfteio.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/a-sfwtio.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/a-siteio.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/a-siwtio.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/a-ssicst.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/a-ssitio.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/a-ssiwti.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/a-stmaco.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/a-strbou.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/a-stream.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/a-strfix.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/a-string.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/a-strmap.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/a-strsea.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/a-strunb.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/a-ststio.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/a-stunau.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/a-stwibo.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/a-stwifi.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/a-stwima.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/a-stwise.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/a-stwiun.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/a-suteio.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/a-swmwco.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/a-sytaco.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/a-tags.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/a-taside.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/a-teioed.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/a-textio.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/a-ticoau.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/a-tideau.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/a-tienau.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/a-tiflau.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/a-tigeau.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/a-tiinau.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/a-timoau.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/a-tiocst.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/a-titest.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/a-witeio.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/a-wtcoau.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/a-wtcstr.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/a-wtdeau.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/a-wtedit.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/a-wtenau.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/a-wtflau.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/a-wtgeau.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/a-wtinau.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/a-wtmoau.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/a-wttest.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/calendar.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/g-busora.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/g-casuti.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/g-comlin.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/g-debuti.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/g-dirope.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/g-hesora.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/g-htable.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/g-io.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/g-io_aux.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/gnat.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/g-os_lib.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/g-regexp.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/g-spipat.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/g-spitbo.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/g-sptabo.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/g-sptain.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/g-sptavs.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/g-tasloc.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/i-c.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/i-cexten.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/i-cobol.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/i-cpp.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/i-cstrea.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/i-cstrin.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/i-fortra.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/interfac.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/ioexcept.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/i-pacdec.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/machcode.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-addima.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-arit64.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-assert.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-asthan.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-auxdec.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-bitops.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-chepoo.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-debpoo.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-direio.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-errrep.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-except.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-exctab.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-exnflt.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-exngen.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-exnint.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-exnlfl.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-exnlin.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-exnllf.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-exnlli.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-exnsfl.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-exnsin.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-exnssi.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-expflt.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-expgen.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-expint.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-explfl.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-io.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-explin.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-expllf.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-explli.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-expllu.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-expmod.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-expsfl.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-expsin.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-expssi.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-expuns.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-fatflt.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-fatlfl.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-fatllf.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-fatsfl.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-ficobl.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-fileio.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-finimp.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-finroo.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-fore.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-imgbiu.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-imgboo.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-imgcha.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-imgdec.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-imgint.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-imgllb.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-imglld.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-imglli.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-imgllu.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-imgllw.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-imgrea.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-imguns.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-imgwch.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-imgwiu.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-inmaop.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-interr.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-intman.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-maccod.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-mantis.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-osinte.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-osprim.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-pack03.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-pack05.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-pack06.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-pack07.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-pack09.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-pack10.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-pack11.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-pack12.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-pack13.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-pack14.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-pack15.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-pack17.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-pack18.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-pack19.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-pack20.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-pack21.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-pack22.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-pack23.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-pack24.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-pack25.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-pack26.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-pack27.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-pack28.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-pack29.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-pack30.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-pack31.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-pack33.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-pack34.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-pack35.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-pack36.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-pack37.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-pack38.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-pack39.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-pack40.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-pack41.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-pack42.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-pack43.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-pack44.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-pack45.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-pack46.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-pack47.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-pack48.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-pack49.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-pack50.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-pack51.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-pack52.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-pack53.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-pack54.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-pack55.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-pack56.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-pack57.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-pack58.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-pack59.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-pack60.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-pack61.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-pack62.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-pack63.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-parame.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-parint.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-pooglo.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-pooloc.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-poosiz.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-powtab.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-proinf.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-rpc.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-secsta.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-sequio.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-sopco3.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-sopco4.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-sopco5.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-stalib.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-std.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-stoele.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-stopoo.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-stratt.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-strops.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-taenca.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-taprob.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-taprop.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-tasabo.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-tasdeb.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-tasinf.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-tasini.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-taskin.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-tasoli.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-taspda.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-taspri.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-tasque.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-tasren.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-tassta.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-tastim.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-tasuti.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-tataat.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-unstyp.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-vaflop.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-valboo.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-valcha.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-valdec.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-valenu.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-valint.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-vallld.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-vallli.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-valllu.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-valrea.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-valuns.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-valuti.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-valwch.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-vercon.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-vmexta.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-wchcnv.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-wchcon.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-wchjis.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-wchstw.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-wchwts.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-widboo.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-widcha.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-widenu.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-widlli.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-widllu.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-widwch.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-wwdcha.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-wwdenu.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-wwdwch.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/system.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/text_io.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-gtplsp.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-gartcp.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-ganobl.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-gaplsp.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-garnam.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-garrem.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-gafizi.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-galiop.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-galite.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-ganata.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-ganeut.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-gaphlo.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-garcon.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-gardeb.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-garfil.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-garexc.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-garhea.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-garlic.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-garloc.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-garopt.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-garela.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-garpri.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-garpro.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-garrep.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-garser.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-garsta.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-gartra.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-gaprco.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-garstr.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-gartab.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-garthi.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-garter.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-gartyp.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-garuni.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-garuti.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-gasoli.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-gatcop.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-rpcpoo.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/s-rpstio.ali
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/libgnat.a
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adalib/libgnat.so
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-astaco.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-cadeob.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-caldel.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-calend.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-chahan.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-colien.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-comlin.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-decima.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-diocst.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-direio.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-dynpri.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-emstop.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-except.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-excpol.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-filico.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-finali.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-interr.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-ngcefu.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-ngcoty.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-ngelfu.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-nudira.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-nuflra.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-reatim.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-retide.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-sequio.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-siocst.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-ssicst.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-storio.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-strbou.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-strfix.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-strmap.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-strsea.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-strunb.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-ststio.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-stunau.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-stwibo.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-stwifi.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-stwima.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-stwise.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-stwiun.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-suteio.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-sytaco.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-tags.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-tasatt.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-taside.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-teioed.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-textio.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-ticoau.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-ticoio.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-tideau.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-tideio.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-tienau.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-tienio.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-tifiio.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-tiflau.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-tiflio.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-tigeau.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-tiinau.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-tiinio.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-timoau.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-timoio.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-tiocst.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-titest.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-witeio.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-wtcoau.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-wtcoio.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-wtcstr.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-wtdeau.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-wtdeio.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-wtedit.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-wtenau.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-wtenio.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-wtfiio.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-wtflau.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-wtflio.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-wtgeau.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-wtinau.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-wtinio.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-wtmoau.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-wtmoio.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-wttest.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/g-busora.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/g-busorg.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/g-casuti.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/g-comlin.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/g-debuti.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/g-dirope.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/g-hesora.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/g-hesorg.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/g-htable.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/g-io.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/g-io_aux.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/g-os_lib.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/g-regexp.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/g-spipat.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/g-spitbo.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/g-table.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/g-tasloc.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/i-c.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/i-cobol.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/i-cpoint.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/i-cpp.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/i-csthre.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/i-cstrea.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/i-cstrin.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/i-fortra.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/i-os2lib.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/i-pacdec.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-addima.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-arit64.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-assert.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-asthan.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-atacco.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-auxdec.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-bitops.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-debpoo.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-direio.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-errrep.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-exctab.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-exngen.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-expgen.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-expllu.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-expmod.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-expuns.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-fatgen.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-fileio.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-finimp.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-finroo.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-fore.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-imgbiu.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-imgboo.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-imgcha.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-imgdec.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-imgint.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-imgllb.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-imglld.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-imglli.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-imgllu.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-imgllw.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-imgrea.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-imguns.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-imgwch.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-imgwiu.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-inmaop.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-interr.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-intman.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-io.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-mantis.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-osinte.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-osprim.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-pack03.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-pack05.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-pack06.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-pack07.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-pack09.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-pack10.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-pack11.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-pack12.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-pack13.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-pack14.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-pack15.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-pack17.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-pack18.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-pack19.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-pack20.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-pack21.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-pack22.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-pack23.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-pack24.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-pack25.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-pack26.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-pack27.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-pack28.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-pack29.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-pack30.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-pack31.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-pack33.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-pack34.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-pack35.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-pack36.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-pack37.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-pack38.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-pack39.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-pack40.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-pack41.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-pack42.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-pack43.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-pack44.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-pack45.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-pack46.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-pack47.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-pack48.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-pack49.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-pack50.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-pack51.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-pack52.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-pack53.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-pack54.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-pack55.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-pack56.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-pack57.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-pack58.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-pack59.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-pack60.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-pack61.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-pack62.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-pack63.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-parame.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-parint.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-pooglo.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-pooloc.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-poosiz.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-proinf.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-rpc.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-secsta.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-sequio.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-sopco3.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-sopco4.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-sopco5.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-stalib.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-std.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-stoele.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-stratt.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-strops.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-taenca.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-taprob.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-taprop.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-tasabo.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-tasdeb.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-tasinf.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-tasini.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-taskin.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-tasoli.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-taspda.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-tasque.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-tasren.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-tassta.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-tastim.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-tasuti.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-tataat.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-vaflop.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-valboo.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-valcha.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-valdec.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-valenu.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-valint.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-vallld.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-vallli.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-valllu.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-valrea.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-valuns.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-valuti.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-valwch.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-vercon.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-vmexta.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-wchcnv.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-wchjis.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-wchstw.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-wchwts.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-widboo.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-widcha.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-widenu.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-widlli.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-widllu.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-widwch.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-wwdcha.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-wwdenu.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-wwdwch.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-astaco.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-cadeob.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-caldel.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-calend.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-chahan.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-charac.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-chlat1.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-colien.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-comlin.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-cwila1.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/ada.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-decima.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-diocst.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-direio.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-dynpri.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-except.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-filico.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-finali.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-flteio.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-fwteio.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-inteio.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-interr.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-intnam.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-ioexce.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-iwteio.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-lfteio.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-lfwtio.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-liteio.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-liwtio.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-llftio.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-llfwti.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-llitio.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-lliwti.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-ncelfu.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-ngcefu.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-ngcoty.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-ngelfu.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-nlcefu.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-nlcoty.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-nlelfu.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-nllcef.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-nllcty.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-nllefu.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-nscefu.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-nscoty.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-nselfu.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-nucoty.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-nudira.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-nuelfu.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-nuflra.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-numaux.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-numeri.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-reatim.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-retide.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-sequio.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-sfteio.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-sfwtio.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-siocst.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-siteio.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-siwtio.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-ssicst.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-ssitio.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-ssiwti.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-stmaco.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-storio.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-strbou.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-stream.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-strfix.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-string.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-strmap.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-strsea.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-strunb.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-ststio.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-stunau.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-stwibo.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-stwifi.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-stwima.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-stwise.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-stwiun.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-suteio.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-swmwco.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-sytaco.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-tags.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-tasatt.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-taside.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-teioed.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-textio.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-ticoau.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-ticoio.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-tideau.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-tideio.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-tienau.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-tienio.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-tifiio.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-tiflau.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-tiflio.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-tigeau.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-tiinau.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-tiinio.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-timoau.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-timoio.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-tiocst.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-titest.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-unccon.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-uncdea.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-witeio.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-wtcoau.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-wtcoio.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-wtcstr.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-wtdeau.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-wtdeio.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-wtedit.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-wtenau.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-wtenio.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-wtfiio.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-wtflau.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-wtflio.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-wtgeau.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-wtinau.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-wtinio.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-wtmoau.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-wtmoio.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/a-wttest.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/calendar.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/directio.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/g-busora.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/g-busorg.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/g-casuti.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/g-comlin.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/g-debuti.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/g-dirope.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/g-hesora.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/g-hesorg.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/g-htable.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/g-io.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/g-io_aux.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/gnat.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/g-os_lib.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/g-regexp.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/g-spipat.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/g-spitbo.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/g-sptabo.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/g-sptain.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/g-sptavs.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/g-table.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/g-tasloc.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/i-c.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/i-cexten.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/i-cobol.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/i-cpoint.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/i-cpp.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/i-csthre.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/i-cstrea.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/i-cstrin.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/i-fortra.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/interfac.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/ioexcept.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/i-os2err.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/i-os2lib.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/i-os2syn.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/i-os2thr.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/i-pacdec.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/machcode.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-addima.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-arit64.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-assert.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-asthan.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-atacco.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-auxdec.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-bitops.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-chepoo.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-debpoo.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-direio.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/sequenio.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-errrep.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-except.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-exctab.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-exnflt.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-exngen.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-exnint.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-exnlfl.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-exnlin.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-exnllf.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-exnlli.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-exnsfl.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-exnsin.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-exnssi.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-expflt.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-expgen.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-expint.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-explfl.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-explin.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-expllf.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-explli.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-expllu.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-expmod.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-expsfl.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-expsin.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-expssi.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-expuns.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-fatflt.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-fatgen.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-fatlfl.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-fatllf.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-fatsfl.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-ficobl.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-fileio.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-finimp.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-finroo.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-fore.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-imgbiu.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-imgboo.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-imgcha.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-imgdec.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-imgint.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-imgllb.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-imglld.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-imglli.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-imgllu.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-imgllw.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-imgrea.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-imguns.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-imgwch.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-imgwiu.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-inmaop.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-interr.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-intman.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-io.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-maccod.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-mantis.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-osinte.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-osprim.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-pack03.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-pack05.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-pack06.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-pack07.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-pack09.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-pack10.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-pack11.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-pack12.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-pack13.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-pack14.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-pack15.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-pack17.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-pack18.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-pack19.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-pack20.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-pack21.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-pack22.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-pack23.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-pack24.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-pack25.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-pack26.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-pack27.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-pack28.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-pack29.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-pack30.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-pack31.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-pack33.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-pack34.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-pack35.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-pack36.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-pack37.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-pack38.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-pack39.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-pack40.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-pack41.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-pack42.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-pack43.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-pack44.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-pack45.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-pack46.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-pack47.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-pack48.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-pack49.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-pack50.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-pack51.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-pack52.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-pack53.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-pack54.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-pack55.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-pack56.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-pack57.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-pack58.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-pack59.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-pack60.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-pack61.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-pack62.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-pack63.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-parame.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-parint.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-pooglo.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-pooloc.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-poosiz.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-powtab.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-proinf.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-rpc.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-secsta.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-sequio.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-sopco3.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-sopco4.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-sopco5.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-stalib.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-std.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-stoele.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-stopoo.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-stratt.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-strops.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-taenca.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-taprob.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-taprop.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-tasabo.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-tasdeb.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-tasinf.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-tasini.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-taskin.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-tasoli.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-taspda.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-taspri.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-tasque.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-tasren.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-tassta.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-tastim.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-tasuti.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-tataat.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-unstyp.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-vaflop.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-valboo.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-valcha.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-valdec.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-valenu.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-valint.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-vallld.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-vallli.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-valllu.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-valrea.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-valuns.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-valuti.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-valwch.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-vercon.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-vmexta.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-wchcnv.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-wchcon.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-wchjis.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-wchstw.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-wchwts.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-widboo.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-widcha.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-widenu.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-widlli.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-widllu.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-widwch.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-wwdcha.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-wwdenu.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-wwdwch.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/system.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/text_io.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/unchconv.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/unchdeal.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-gtplsp.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-gartcp.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-gartcp.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-ganobl.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-ganobl.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-gaplsp.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-garnam.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-garnam.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-garrem.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-garrem.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-gafizi.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-gafizi.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-galiop.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-galite.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-galite.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-ganeut.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-ganeut.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-gaphlo.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-gaphlo.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-garcon.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-gardeb.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-gardeb.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-garfil.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-garfil.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-garhea.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-garhea.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-garlic.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-garloc.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-garloc.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-garopt.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-garopt.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-garpro.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-garpri.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-ganata.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-ganata.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-garpro.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-garexc.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-garexc.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-garrep.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-garrep.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-garser.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-garser.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-garsta.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-garsta.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-garstr.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-garstr.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-garthi.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-gartra.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-gartra.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-gaprco.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-gaprco.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-garela.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-garela.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-garter.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-garter.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-gartab.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-gartab.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-gartyp.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-gartyp.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-garuni.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-garuni.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-garuti.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-garuti.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-gasoli.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-gasoli.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-gatcop.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-gastha.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-gastha.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-rpcpoo.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-rpcpoo.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-rpstio.ads
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/adainclude/s-rpstio.adb
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/cc1
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/gnat1
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/crtbegin.o
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/crtbeginS.o
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/crtend.o
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/crtendS.o
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/specs
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/cpp
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/libgnatgcc.a
/usr/lib/gcc-lib/i386-Ada95-linux/2.8.1/libgnat.so

%files rts
/usr/lib/libgnat.so
/usr/lib/libgnat.so.3.11
/usr/lib/libasis.so
/usr/lib/libasis.so.3.11

%clean
rm -rf $RPM_BUILD_ROOT

%changelog
* Wed Jan 27 1999 Juergen Pfeifer <juergen.pfeifer@t-online.de>
- Make separate package for GNAT runtime (prereq. for compiler)
- Install also gnathtml
- Added asis (static and shared library version)
- Install gnatstub and gnatelim
- Eliminate LD_LIBRARY_PATH setting in profile scripts. We will
  always make symlinks in /usr/lib

* Tue Jan 26 1999 Juergen Pfeifer <juergen.pfeifer@t-online.de>
- Specfile for RH and patches to compile on RH to build shared library
  and other driver name than "gcc".
